package io.scanbot.sdk.plugin.cordova

import io.scanbot.sdk.sdk_native_wrapper.SBNWOperations
import org.apache.cordova.CallbackContext
import org.apache.cordova.CordovaPlugin
import org.json.JSONArray


class ScanbotSDKPlugin : CordovaPlugin() {


  override fun execute(
    action: String?,
    args: JSONArray,
    callbackContext: CallbackContext
  ): Boolean {

    fun threadPoolWrapper(fn: () -> Unit): Boolean {
      cordova.threadPool.execute {
        try {
          fn()
        } catch (e: Exception) {
          callbackContext.error(e.message ?: "An unexpected error has occurred")
        }
      }
      return true
    }

    return when (action) {
      "initializeSdk" -> threadPoolWrapper { initializeSDK(args, callbackContext) }
      "getLicenseInfo" -> threadPoolWrapper { getLicenseInfo(callbackContext) }
      "detectBarcodesOnImage" -> threadPoolWrapper {
        detectBarcodesOnImage(args, callbackContext)
      }

      "detectBarcodesOnImages" -> threadPoolWrapper {
        detectBarcodesOnImages(args, callbackContext)
      }

      "applyImageFilter" -> threadPoolWrapper {
        applyImageFilter(args, callbackContext)
      }

      "applyImageFilterOnPage" -> threadPoolWrapper {
        applyImageFilterOnPage(args, callbackContext)
      }

      "getImageData" -> threadPoolWrapper { getImageData(args, callbackContext) }
      "rotateImage" -> threadPoolWrapper { rotateImage(args, callbackContext) }
      "createPage" -> threadPoolWrapper { createPage(args, callbackContext) }
      "removePage" -> threadPoolWrapper { removePage(args, callbackContext) }
      "rotatePage" -> threadPoolWrapper { rotatePage(args, callbackContext) }
      "setDocumentImage" -> threadPoolWrapper { setDocumentImage(args, callbackContext) }
      "detectDocument" -> threadPoolWrapper { detectDocument(args, callbackContext) }
      "detectDocumentOnPage" -> threadPoolWrapper {
        detectDocumentOnPage(
          args,
          callbackContext
        )
      }

      "documentQualityAnalyzer" -> threadPoolWrapper {
        documentQualityAnalyzer(
          args,
          callbackContext
        )
      }

      "extractPagesFromPdf" -> threadPoolWrapper {
        extractPagesFromPdf(
          args,
          callbackContext
        )
      }

      "extractImagesFromPdf" -> threadPoolWrapper {
        extractImagesFromPdf(
          args,
          callbackContext
        )
      }

      "recognizeCheckOnImage" -> threadPoolWrapper { recognizeCheck(args, callbackContext) }
      "recognizeMrz" -> threadPoolWrapper { recognizeMrz(args, callbackContext) }
      "refreshImageUris" -> threadPoolWrapper { refreshImageUris(args, callbackContext) }
      "getOcrConfigs" -> threadPoolWrapper { getOCRConfigs(callbackContext) }
      "cleanup" -> threadPoolWrapper { cleanup(callbackContext) }
      "getFilteredDocumentPreviewUri" -> threadPoolWrapper {
        getFilteredDocumentPreviewUri(args, callbackContext)
      }

      "performOcr" -> threadPoolWrapper { performOCR(args, callbackContext) }
      "createPdf" -> threadPoolWrapper { createPDF(args, callbackContext) }
      "writeTiff" -> threadPoolWrapper { writeTIFF(args, callbackContext) }

      else -> false
    }
  }

  private fun initializeSDK(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.initializeSdk(
      cordova.activity.application,
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun getLicenseInfo(callbackContext: CallbackContext) {
    SBNWOperations.getLicenseInfo(ResultDelegate(callbackContext))
  }

  private fun detectBarcodesOnImage(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.detectBarcodesOnImage(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun detectBarcodesOnImages(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.detectBarcodesOnImages(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun applyImageFilter(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.applyImageFilter(
      args.itemToString("imageFileUri"),
      args.itemToString("imageFilter"),
      ResultDelegate(callbackContext)
    );
  }

  private fun applyImageFilterOnPage(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.applyImageFilterOnPage(
      args.itemToMap("page"),
      args.itemToString("imageFilter"),
      ResultDelegate(callbackContext)
    )
  }

  private fun getImageData(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.getImageData(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun rotateImage(args: JSONArray, callbackContext: CallbackContext) {
    SBNWOperations.rotateImage(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun createPage(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.createPage(
      args.itemToString("originalImageFileUri"),
      ResultDelegate(callbackContext)
    )
  }

  private fun removePage(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.removePage(
      args.itemToMap("page"),
      ResultDelegate(callbackContext)
    )
  }

  private fun rotatePage(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.rotatePage(
      args.itemToMap("page"),
      args.itemToInt("times"),
      ResultDelegate(callbackContext)
    )
  }

  private fun setDocumentImage(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.setDocumentImage(
      mapOf(
        "imageFileUri" to args.itemToString("documentImageFileUri"),
        "page" to args.itemToMap("page")
      ),
      ResultDelegate(callbackContext)
    )
  }

  private fun detectDocument(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.detectDocumentOnImage(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun detectDocumentOnPage(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.detectDocumentOnPage(
      args.itemToMap("page"),
      ResultDelegate(callbackContext)
    )
  }

  private fun documentQualityAnalyzer(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.documentQualityAnalyzer(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun extractImagesFromPdf(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.extractImagesFromPdf(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun extractPagesFromPdf(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.extractPagesFromPdf(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun recognizeCheck(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.recognizeCheckOnImage(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun recognizeMrz(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.recognizeMrz(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun refreshImageUris(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.refreshImageUris(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun getOCRConfigs(callbackContext: CallbackContext) {
    SBNWOperations.getOCRConfigs(ResultDelegate(callbackContext))
  }

  private fun cleanup(callbackContext: CallbackContext) {
    SBNWOperations.cleanup(ResultDelegate(callbackContext))
  }

  private fun getFilteredDocumentPreviewUri(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.getFilteredDocumentPreviewUri(
      args.itemToMap("page"),
      args.itemToString("imageFilter"),
      ResultDelegate(callbackContext)
    )
  }

  private fun performOCR(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.performOCR(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

  private fun createPDF(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    val imageFileUris = args.itemToStringList("imageFileUris")
    var pageSize:String? = null
    var pageDirection: String? = null
    var pdfAttributes: Map<String,Any>? = null
    args.getJSONObject(0).optJSONObject("options")?.let {
      pageSize = it.optString("pageSize")
      pageDirection = it.optString("pageOrientation")
      pdfAttributes = it.optJSONObject("metadata")?.itemToMap()
    }
    SBNWOperations.createPDF(
      imageFileUris,
      pageSize,
      pageDirection,
      pdfAttributes,
      ResultDelegate(callbackContext)
    )
  }

  private fun writeTIFF(
    args: JSONArray,
    callbackContext: CallbackContext
  ) {
    SBNWOperations.createTIFF(
      args.itemToMap(),
      ResultDelegate(callbackContext)
    )
  }

}
