
import Foundation
import ScanbotSDKNativeWrapper

@objc(ScanbotSDKPlugin) class ScanbotSDKPlugin : CDVPlugin {

    func backgroundWrapper(sdkFn:@escaping () -> Void) {
        self.commandDelegate.run(inBackground: {
            sdkFn()
        })
    }

    func createDelegate(_ callbackId:String) -> ResultDelegate {
        return ResultDelegate(
            commandDelegate: self.commandDelegate,
            callbackId: callbackId
        )
    }

    func sendError(callbackId: String, message: String){
        self.commandDelegate.send(
            CDVPluginResult(
                status: CDVCommandStatus_ERROR,
                messageAs: [
                    "message":message
                ]
            ),
            callbackId: callbackId)
    }

    func invalidArgument(_ callbackId: String){
        sendError(callbackId: callbackId, message: "Invalid arguments provided")
    }

    @objc(initializeSdk:)
    func initializeSdk(command: CDVInvokedUrlCommand) {
        if var options = command.itemAtIndexToMap() {
            backgroundWrapper {
                options["isCordova"] = true
                SBNWOperations.initializeSDK(
                    options:options,
                    delegate: ResultDelegate(
                        commandDelegate: self.commandDelegate,
                        callbackId: command.callbackId
                    )
                )
            }
        } else {
            sendError(callbackId: command.callbackId, message: "Initialization error")
        }

    }

    @objc(getLicenseInfo:)
    func getLicenseInfo(command: CDVInvokedUrlCommand){
        backgroundWrapper {
            SBNWOperations.getLicenseInfo(withDelegate: self.createDelegate(command.callbackId))
        }
    }

    @objc(detectBarcodesOnImage:)
    func detectBarcodesOnImage(command: CDVInvokedUrlCommand){
        guard let configuration = command.itemAtIndexToMap()
        else {
            return invalidArgument(command.callbackId)
        }
        backgroundWrapper {
            SBNWOperations.detectBarcodesOnImage(
                configuration: configuration,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(detectBarcodesOnImages:)
    func detectBarcodesOnImages(command: CDVInvokedUrlCommand){
        guard let configuration = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.detectBarcodesOnImages(
                configuration: configuration,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(applyImageFilter:)
    func applyImageFilter(command: CDVInvokedUrlCommand){
        guard let imageFileUri = command.itemAtIndexToString(key: "imageFileUri"),
              let filterType = command.itemAtIndexToString(key: "imageFilter")
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.applyImageFilter(
                imageFileUri: imageFileUri,
                filter: filterType,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(applyImageFilterOnPage:)
    func applyImageFilterOnPage(command: CDVInvokedUrlCommand){
        guard let page = command.itemAtIndexToMap(key: "page"),
              let filterType = command.itemAtIndexToString(key: "imageFilter")
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.applyImageFilterOnPage(
                pageDict: page,
                filter: filterType,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(getImageData:)
    func getImageData(command: CDVInvokedUrlCommand){
        guard let imageUrl = command.itemAtIndexToString(key: "imageFileUri")
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.getImageData(
                imageFileUri: imageUrl,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(rotateImage:)
    func rotateImage(command: CDVInvokedUrlCommand){
        guard let imageFileUri = command.itemAtIndexToString(key: "imageFileUri"),
              let degrees = command.itemAtIndexToDouble(key: "degrees")
        else{
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.rotateImage(
                imageFileUri: imageFileUri,
                degrees: degrees,
                delegate: self.createDelegate(command.callbackId))
        }
    }

    @objc(createPage:)
    func createPage(command: CDVInvokedUrlCommand){
        guard let imageUri = command.itemAtIndexToString(key:"originalImageFileUri")
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.createPage(
                imageFileUri: imageUri,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(removePage:)
    func removePage(command: CDVInvokedUrlCommand){
        guard let page = command.itemAtIndexToMap(key:"page")
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.removePage(
                pageDict: page,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(rotatePage:)
    func rotatePage(command: CDVInvokedUrlCommand){
        guard let page = command.itemAtIndexToMap(key:"page"),
              let times = command.itemAtIndexToInt(key:"times")
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.rotatePage(
                pageDict: page,
                times: times,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(setDocumentImage:)
    func setDocumentImage(command: CDVInvokedUrlCommand){
        guard let page = command.itemAtIndexToMap(key:"page"),
              let imageFileUri = command.itemAtIndexToString(key:"documentImageFileUri")
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.setDocumentImage(
                configuration: [
                    "page": page,
                    "imageFileUri": imageFileUri
                ],
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(detectDocument:)
    func detectDocument(command: CDVInvokedUrlCommand){
        guard let configuration = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.detectDocument(
                configuration: configuration,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(detectDocumentOnPage:)
    func detectDocumentOnPage(command: CDVInvokedUrlCommand){
        guard let page = command.itemAtIndexToMap(key:"page")
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.detectDocumentOnPage(
                pageDict: page,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(documentQualityAnalyzer:)
    func documentQualityAnalyzer(command: CDVInvokedUrlCommand){
        guard let args = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.documentQualityAnalyzer(
                args: args,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(extractImagesFromPdf:)
    func extractImagesFromPdf(command: CDVInvokedUrlCommand){
        guard let configuration = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.extractImagesFromPdf(
                configuration: configuration,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(extractPagesFromPdf:)
    func extractPagesFromPdf(command: CDVInvokedUrlCommand){
        guard let configuration = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.extractPagesFromPdf(
                configuration: configuration,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(recognizeCheckOnImage:)
    func recognizeCheckOnImage(command: CDVInvokedUrlCommand){
        guard let configuration = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.recognizeCheckOnImage(
                configuration: configuration,
                delegate: self.createDelegate(command.callbackId))
        }
    }

    @objc(recognizeMrz:)
    func recognizeMrz(command: CDVInvokedUrlCommand){
        guard let configuration = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.recognizeMrz(
                configuration: configuration,
                delegate: self.createDelegate(command.callbackId))
        }
    }

    @objc(refreshImageUris:)
    func refreshImageUris(command: CDVInvokedUrlCommand){
        guard let pageUriMap = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.refreshImageUris(
                configuration: pageUriMap,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(getOcrConfigs:)
    func getOcrConfigs(command: CDVInvokedUrlCommand){
        backgroundWrapper {
            SBNWOperations.getOCRConfigs(withDelegate: self.createDelegate(command.callbackId))
        }
    }

    @objc(cleanup:)
    func cleanup(command: CDVInvokedUrlCommand){
        backgroundWrapper {
            SBNWOperations.cleanup(delegate: self.createDelegate(command.callbackId))
        }
    }

    @objc(getFilteredDocumentPreviewUri:)
    func getFilteredDocumentPreviewUri(command: CDVInvokedUrlCommand){
        guard let page = command.itemAtIndexToMap(key:"page"),
              let filter = command.itemAtIndexToString(key: "imageFilter")
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.getFilteredDocumentPreviewUri(
                pageDict: page,
                filter: filter,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(performOcr:)
    func performOcr(command: CDVInvokedUrlCommand){
        guard let configuration = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.performOCR(
                configuration: configuration,
                delegate: self.createDelegate(command.callbackId))
        }
    }

    @objc(createPdf:)
    func createPdf(command: CDVInvokedUrlCommand){
        guard let imageFileUris = command.itemAtIndexToStringList(key: "imageFileUris")
        else {
            invalidArgument(command.callbackId)
            return
        }
        var pageSize: String = "A4"
        var pageOrientation: String? = nil
        var pdfMetadata: [String:String]? = nil

        if let options = command.itemAtIndexToMap(key: "options") {
            if let pageSizeArg = options["pageSize"] as? String  {
                pageSize = pageSizeArg
            }
            pageOrientation = options["pageOrientation"] as? String
            pdfMetadata = options["metadata"] as? [String:String]

        }
        backgroundWrapper {
            SBNWOperations.createPDF(
                imageFileUris: imageFileUris,
                pageSize: pageSize,
                pageOrientation: pageOrientation,
                pdfMetadata: pdfMetadata,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

    @objc(writeTiff:)
    func writeTiff(command: CDVInvokedUrlCommand){
        guard let configuration = command.itemAtIndexToMap()
        else {
            invalidArgument(command.callbackId)
            return
        }
        backgroundWrapper {
            SBNWOperations.writeTIFF(
                configuration: configuration,
                delegate: self.createDelegate(command.callbackId)
            )
        }
    }

}
